<?php

namespace Wappointment\Controllers;

use Wappointment\ClassConnect\Request;
use Wappointment\ClassConnect\Carbon;
use Wappointment\Services\Settings;
use Wappointment\Services\DateTime;
use Wappointment\Services\Status;
use Wappointment\WP\Helpers as WPHelpers;
use Wappointment\Models\Status as Mstatus;
use Wappointment\Models\Appointment as AppointmentModel;
use Wappointment\Services\Appointment;
class EventsController extends \Wappointment\Controllers\RestController
{
    private $timezone = '';
    private function TESTprocessAvail($avails)
    {
        foreach ($avails as &$avail) {
            $avail[0] = \Wappointment\ClassConnect\Carbon::createFromTimestamp($avail[0])->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00 T');
            $avail[1] = \Wappointment\ClassConnect\Carbon::createFromTimestamp($avail[1])->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00 T');
        }
        return $avails;
    }
    public function get(\Wappointment\ClassConnect\Request $request)
    {
        $this->timezone = $request->input('timezone');
        return [
            'events' => \array_merge($this->events($request), $this->regavToBgEvent($request)),
            'availability' => \Wappointment\WP\Helpers::getStaffOption('availability'),
            //$this->TESTprocessAvail(Settings::getStaff('availability')),
            'now' => (new \Wappointment\ClassConnect\Carbon())->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00'),
        ];
    }
    public function delete(\Wappointment\ClassConnect\Request $request)
    {
        $appointment = \Wappointment\Models\Appointment::where('id', $request->input('id'))->first();
        if (\Wappointment\Services\Appointment::cancel($appointment)) {
            return ['message' => 'Appointment cancelled'];
        }
        throw new \WappointmentException('Error deleting appointment', 1);
    }
    public function put(\Wappointment\ClassConnect\Request $request)
    {
        if (\Wappointment\Services\Appointment::confirm($request->input('id'))) {
            return ['message' => 'Appointment confirmed'];
        } else {
            throw new \WappointmentException('Appointment couldn\'t be confirmed', 1);
        }
    }
    public function patch(\Wappointment\ClassConnect\Request $request)
    {
        $this->timezone = $request->input('timezone');
        if (\Wappointment\Services\Appointment::patch($request->input('id'), ['start_at' => \Wappointment\Services\DateTime::convertUnixTS($request->input('start')), 'end_at' => \Wappointment\Services\DateTime::convertUnixTS($request->input('end'))])) {
            return ['message' => 'Appointment updated'];
        } else {
            throw new \WappointmentException('Appointment couldn\'t be updated', 1);
        }
    }
    private function convertTime($dateString)
    {
        return (new \Wappointment\ClassConnect\Carbon($dateString))->setTimezone($this->timezone)->toDateTimeString();
    }
    private function prepareClient($client)
    {
        if (isset($client->email)) {
            $client->avatar = get_avatar_url($client->email, ['size' => 30]);
        }
        return $client;
    }
    private function getAppointments($start_at_string, $end_at_string)
    {
        return \Wappointment\Models\Appointment::with('client')->where('status', '>=', \Wappointment\Models\Appointment::STATUS_AWAITING_CONFIRMATION)->where('start_at', '>=', $start_at_string)->where('end_at', '<=', $end_at_string)->get();
    }
    private function events(\Wappointment\ClassConnect\Request $request)
    {
        $ends_at_carbon = \Wappointment\Services\DateTime::timeZToUtc($request->input('end'));
        $start_at_string = \Wappointment\Services\DateTime::timeZToUtc($request->input('start'))->format(WAPPOINTMENT_DB_FORMAT);
        $end_at_string = $ends_at_carbon->format(WAPPOINTMENT_DB_FORMAT);
        $events = [];
        $appointments = apply_filters('wappointment_calendar_events_query', [], ['start_at' => $start_at_string, 'end_at' => $end_at_string]);
        if (empty($appointments)) {
            $appointments = $this->getAppointments($start_at_string, $end_at_string);
        }
        foreach ($appointments as $event) {
            $addedEvent = ['start' => $event->start_at->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00'), 'end' => $event->end_at->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00'), 'id' => $event->id, 'delId' => $event->id, 'location' => $event->getLocationSlug(), 'status' => $event->status, 'client' => $this->prepareClient($event->client), 'type' => 'appointment', 'onlyDelete' => true, 'rendering' => (bool) $event->status ? 'appointment-confirmed' : 'appointment-pending', 'className' => (bool) $event->status ? 'appointment-confirmed' : 'appointment-pending'];
            $events[] = apply_filters('wappointment_appointment_get_filter', $addedEvent, $event);
        }
        $statusEvents = \Wappointment\Models\Status::where('start_at', '<', $end_at_string)->where('end_at', '>', $start_at_string)->where('muted', '<', 1)->get();
        $recurringBusy = \Wappointment\Models\Status::where('recur', '>', \Wappointment\Models\Status::RECUR_NOT)->where('muted', '<', 1)->get();
        /* dd($recurringBusy->toArray()); */
        $sixtydaysinsecs = 60 * 24 * 3600;
        $punctualEvent = \Wappointment\Services\Status::expand($recurringBusy, $ends_at_carbon->timestamp + $sixtydaysinsecs);
        $statusEvents = $statusEvents->concat($punctualEvent);
        //dd($statusEvents);
        foreach ($statusEvents as $event) {
            $addedEvent = ['start' => $event->start_at->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00'), 'end' => $event->end_at->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00'), 'id' => $event->recur > \Wappointment\Models\Status::RECUR_NOT ? \time() : $event->id, 'delId' => $event->id, 'recur' => $event->recur, 'source' => empty($event->source) ? '' : $event->source, 'onlyDelete' => true, 'rendering' => 'background'];
            if ($event->type == \Wappointment\Models\Status::TYPE_FREE) {
                $addedEvent['className'] = 'opening extra';
                $addedEvent['type'] = 'free';
            } else {
                if (empty($event->source)) {
                    $addedEvent['className'] = 'busy';
                    $addedEvent['type'] = 'busy';
                    if ($request->input('view') == 'month') {
                        $addedEvent['allDay'] = true;
                    }
                } else {
                    if ($event->recur > 0) {
                        $addedEvent['className'] = 'calendar recurrent';
                        $addedEvent['type'] = 'calendar';
                        $addedEvent['options'] = $event->options;
                    } else {
                        $addedEvent['className'] = 'calendar';
                        $addedEvent['type'] = 'calendar';
                        $addedEvent['options'] = $event->options;
                    }
                }
            }
            $events[] = $addedEvent;
        }
        return $events;
    }
    private function regavToBgEvent(\Wappointment\ClassConnect\Request $request)
    {
        $bg_events = [];
        $this->regav = \Wappointment\Services\Settings::getStaff('regav');
        $regavTimezone = \Wappointment\Services\Settings::getStaff('timezone');
        $startDate = new \Wappointment\ClassConnect\Carbon($request->input('start'), $this->timezone);
        $daysOfTheWeek = ['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday'];
        while (\count($daysOfTheWeek) > 0) {
            $dayName = $daysOfTheWeek[$startDate->dayOfWeek];
            foreach ($this->regav[$dayName] as $dayTimeblock) {
                $start = (new \Wappointment\ClassConnect\Carbon($startDate->format(WAPPOINTMENT_DB_FORMAT . ':00'), $regavTimezone))->hour($dayTimeblock[0]);
                $end = (new \Wappointment\ClassConnect\Carbon($startDate->format(WAPPOINTMENT_DB_FORMAT . ':00'), $regavTimezone))->hour($dayTimeblock[1]);
                $bg_events[] = ['start' => $start->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00'), 'end' => $end->setTimezone($this->timezone)->format('Y-m-d\\TH:i:00'), 'rendering' => 'background', 'className' => 'opening', 'type' => 'ra'];
            }
            unset($daysOfTheWeek[$startDate->dayOfWeek]);
            $startDate->addDay(1);
        }
        return $bg_events;
    }
}
