<?php

namespace Wappointment\Controllers;

use Wappointment\ClassConnect\Request;
use Wappointment\Services\Reminder;
use Wappointment\Models\Reminder as MReminder;
use Wappointment\Services\Settings;
class ReminderController extends \Wappointment\Controllers\RestController
{
    private $columns = ['id', 'subject', 'type', 'event', 'locked', 'published', 'options'];
    public function save(\Wappointment\ClassConnect\Request $request)
    {
        $requested = $request->all();
        $requested['published'] = true;
        if ($this->isTrueOrFail(\Wappointment\Services\Reminder::save($requested))) {
            return ['message' => 'Reminder saved'];
        } else {
            throw new \WappointmentException('Couldn\'t save preview', 1);
        }
    }
    public function patch(\Wappointment\ClassConnect\Request $request)
    {
        if ($this->isTrueOrFail(\Wappointment\Services\Reminder::save($request->except(['locked'])))) {
            return ['message' => 'Reminder updated'];
        } else {
            throw new \WappointmentException('Couldn\'t update reminder', 1);
        }
    }
    public function preview(\Wappointment\ClassConnect\Request $request)
    {
        if ($this->isTrueOrFail(\Wappointment\Services\Reminder::preview($request->input('reminder'), $request->input('recipient')))) {
            return ['message' => 'Reminder preview sent'];
        } else {
            throw new \WappointmentException('Couldn\'t send preview', 1);
        }
    }
    public function delete(\Wappointment\ClassConnect\Request $request)
    {
        if (\Wappointment\Services\Reminder::delete($request->input('id'))) {
            return ['message' => 'Reminder deleted'];
        }
        throw new \WappointmentException('Impossible to delete reminder', 1);
    }
    public function get()
    {
        $queryReminders = \Wappointment\Models\Reminder::select($this->columns);
        if ((int) \Wappointment\Services\Settings::get('approval_mode') == 1) {
            $queryReminders->whereNotIn('event', [\Wappointment\Models\Reminder::APPOINTMENT_PENDING]);
        }
        if ((int) \Wappointment\Services\Settings::get('allow_rescheduling') != 1) {
            $queryReminders->whereNotIn('event', [\Wappointment\Models\Reminder::APPOINTMENT_RESCHEDULED]);
        }
        if ((int) \Wappointment\Services\Settings::get('allow_cancellation') != 1) {
            $queryReminders->whereNotIn('event', [\Wappointment\Models\Reminder::APPOINTMENT_CANCELLED]);
        }
        return ['mail_status' => (bool) \Wappointment\Services\Settings::get('mail_status'), 'allow_cancellation' => (bool) \Wappointment\Services\Settings::get('allow_cancellation'), 'allow_rescheduling' => (bool) \Wappointment\Services\Settings::get('allow_rescheduling'), 'reschedule_link' => \Wappointment\Services\Settings::get('reschedule_link'), 'cancellation_link' => \Wappointment\Services\Settings::get('cancellation_link'), 'save_appointment_text_link' => \Wappointment\Services\Settings::get('save_appointment_text_link'), 'recipient' => (new \Wappointment\WP\Staff())->emailAddress(), 'multiple_service_type' => \Wappointment\Helpers\Service::hasMultipleTypes(), 'reminders' => $queryReminders->get(), 'defaultReminder' => \Wappointment\Services\Reminder::getSeedReminder(), 'labels' => ['types' => \Wappointment\Models\Reminder::$types, 'events' => \Wappointment\Models\Reminder::$events]];
    }
}
