<?php

namespace Wappointment\Messages;

use Wappointment\Services\Settings;
use Wappointment\Services\Sections;
use Wappointment\WP\Helpers as WPHelpers;
use Wappointment\Services\Service;
class AdminWeeklySummaryEmail extends \Wappointment\Messages\AdminDailySummaryEmail
{
    private $sections = null;
    public function startWeek()
    {
        return $this->tomorrowCarbon();
    }
    public function endWeek()
    {
        return $this->tomorrowCarbon()->addDays(6);
    }
    public function loadEmail()
    {
        $this->loadNextWeekData();
        $startingDay = $this->startWeek();
        $endDay = $this->endWeek();
        $date_start_string = $startingDay->toDateString();
        $date_end_string = $endDay->toDateString();
        $this->subject = 'Weekly summary ' . $date_start_string . ' - ' . $date_end_string;
        $this->addLogo();
        $this->addBr();
        $tz = \Wappointment\Services\Settings::getStaff('timezone');
        $serviceDurationInSeconds = \Wappointment\Services\Service::get()['duration'] * 60;
        $coverage = $this->sections->getCoverage($serviceDurationInSeconds);
        if (!empty($coverage)) {
            $contentBlock = ['<center>' . 'Appointments: ' . \count($this->sections->appointments) . '</center>', '<center>' . 'Free slots: ' . $this->sections->getFreeSlots($serviceDurationInSeconds) . ' (duration ' . \Wappointment\Services\Service::get()['duration'] . 'min)</center>', '<center>' . 'Coverage: ' . $coverage . '</center>'];
            $this->addRoundedSquare($contentBlock, false);
            if ($this->sections->getFreeSlots($serviceDurationInSeconds) == 0) {
                $this->addButton('Set new availabilities for next week', \Wappointment\WP\Helpers::adminUrl('wappointment_calendar'));
            }
        } else {
            $this->addRoundedSquare(['<center>No availabilities for the week of ' . $date_start_string . ' - ' . $date_end_string . '</center>'], false);
            $this->addButton('Set availabilities for next week', \Wappointment\WP\Helpers::adminUrl('wappointment_calendar'));
        }
        $appointmentSumarry = [];
        $appointmentGroupedByDay = $this->sections->appointments->mapToGroups(function ($item, $key) {
            return [$item->start_at->setTimezone($tz)->toDateString() => $item];
        });
        while ($startingDay->lessThanOrEqualTo($endDay)) {
            $appointmentSumarry[] = '<strong>' . $startingDay->format('D Y-m-d') . '</strong>';
            $appointmentSumarry[] = '<hr/>';
            if (isset($appointmentGroupedByDay[$startingDay->toDateString()])) {
                foreach ($appointmentGroupedByDay[$startingDay->toDateString()] as $appointment) {
                    $appointmentSumarry[] = $appointment->start_at->setTimezone($tz)->format(\Wappointment\Services\Settings::get('time_format')) . ' ' . $appointment->client->name . ' / ' . $appointment->getDuration() . '<br>' . $appointment->client->email;
                }
            } else {
                $appointmentSumarry[] = '<small>No appointments for that day</small>';
            }
            $appointmentSumarry[] = ' ';
            $startingDay->addDay();
        }
        $this->addRoundedSquare($appointmentSumarry);
    }
    private function loadNextWeekData()
    {
        $this->sections = new \Wappointment\Services\Sections($this->startWeek()->timestamp, $this->endWeek()->timestamp);
    }
}
