<?php

namespace Wappointment\Transports;

use WappoVendor\WappoSwift_Mime_SimpleMessage;
use WappoVendor\GuzzleHttp\ClientInterface;
class Mailgun extends \Wappointment\Transports\Transport
{
    /**
     * Guzzle client instance.
     *
     * @var \GuzzleHttp\ClientInterface
     */
    protected $client;
    /**
     * The Mailgun API key.
     *
     * @var string
     */
    protected $key;
    /**
     * The Mailgun domain.
     *
     * @var string
     */
    protected $domain;
    /**
     * The Mailgun API end-point.
     *
     * @var string
     */
    protected $url;
    /**
     * Create a new Mailgun transport instance.
     *
     * @param  \GuzzleHttp\ClientInterface  $client
     * @param  string  $key
     * @param  string  $domain
     * @return void
     */
    public function __construct(\WappoVendor\GuzzleHttp\ClientInterface $client, $domain, $key)
    {
        $this->key = $key;
        $this->client = $client;
        $this->setDomain($domain);
    }
    /**
     * {@inheritdoc}
     */
    public function send(\WappoSwift_Mime_SimpleMessage $message, &$failedRecipients = null)
    {
        $this->beforeSendPerformed($message);
        $to = $this->getTo($message);
        $message->setBcc([]);
        $this->client->post($this->url, $this->payload($message, $to));
        $this->sendPerformed($message);
        return $this->numberOfRecipients($message);
    }
    /**
     * Get the HTTP payload for sending the Mailgun message.
     *
     * @param  \WappoSwift_Mime_SimpleMessage  $message
     * @param  string  $to
     * @return array
     */
    protected function payload(\WappoSwift_Mime_SimpleMessage $message, $to)
    {
        return ['auth' => ['api', $this->key], 'multipart' => [['name' => 'to', 'contents' => $to], ['name' => 'message', 'contents' => $message->toString(), 'filename' => 'message.mime']]];
    }
    /**
     * Get the "to" payload field for the API request.
     *
     * @param  \WappoSwift_Mime_SimpleMessage  $message
     * @return string
     */
    protected function getTo(\WappoSwift_Mime_SimpleMessage $message)
    {
        return \WappointmentLv::collect($this->allContacts($message))->map(function ($display, $address) {
            return $display ? $display . " <{$address}>" : $address;
        })->values()->implode(',');
    }
    /**
     * Get all of the contacts for the message.
     *
     * @param  \WappoSwift_Mime_SimpleMessage  $message
     * @return array
     */
    protected function allContacts(\WappoSwift_Mime_SimpleMessage $message)
    {
        return \array_merge((array) $message->getTo(), (array) $message->getCc(), (array) $message->getBcc());
    }
    /**
     * Get the API key being used by the transport.
     *
     * @return string
     */
    public function getKey()
    {
        return $this->key;
    }
    /**
     * Set the API key being used by the transport.
     *
     * @param  string  $key
     * @return string
     */
    public function setKey($key)
    {
        return $this->key = $key;
    }
    /**
     * Get the domain being used by the transport.
     *
     * @return string
     */
    public function getDomain()
    {
        return $this->domain;
    }
    /**
     * Set the domain being used by the transport.
     *
     * @param  string  $domain
     * @return string
     */
    public function setDomain($domain)
    {
        $this->url = 'https://api.mailgun.net/v3/' . $domain . '/messages.mime';
        return $this->domain = $domain;
    }
}
