<?php

namespace WappoVendor\Doctrine\Common\Collections;

use WappoVendor\Doctrine\Common\Collections\Expr\Comparison;
use WappoVendor\Doctrine\Common\Collections\Expr\CompositeExpression;
use WappoVendor\Doctrine\Common\Collections\Expr\Value;
use function func_get_args;
/**
 * Builder for Expressions in the {@link Selectable} interface.
 *
 * Important Notice for interoperable code: You have to use scalar
 * values only for comparisons, otherwise the behavior of the comparison
 * may be different between implementations (Array vs ORM vs ODM).
 */
class ExpressionBuilder
{
    /**
     * @param mixed ...$x
     *
     * @return CompositeExpression
     */
    public function andX($x = null)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\CompositeExpression(\WappoVendor\Doctrine\Common\Collections\Expr\CompositeExpression::TYPE_AND, \func_get_args());
    }
    /**
     * @param mixed ...$x
     *
     * @return CompositeExpression
     */
    public function orX($x = null)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\CompositeExpression(\WappoVendor\Doctrine\Common\Collections\Expr\CompositeExpression::TYPE_OR, \func_get_args());
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function eq($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::EQ, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function gt($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::GT, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function lt($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::LT, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function gte($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::GTE, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function lte($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::LTE, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function neq($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::NEQ, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     *
     * @return Comparison
     */
    public function isNull($field)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::EQ, new \WappoVendor\Doctrine\Common\Collections\Expr\Value(null));
    }
    /**
     * @param string $field
     * @param array  $values
     *
     * @return Comparison
     */
    public function in($field, array $values)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::IN, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($values));
    }
    /**
     * @param string $field
     * @param array  $values
     *
     * @return Comparison
     */
    public function notIn($field, array $values)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::NIN, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($values));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function contains($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::CONTAINS, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function memberOf($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::MEMBER_OF, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function startsWith($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::STARTS_WITH, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
    /**
     * @param string $field
     * @param mixed  $value
     *
     * @return Comparison
     */
    public function endsWith($field, $value)
    {
        return new \WappoVendor\Doctrine\Common\Collections\Expr\Comparison($field, \WappoVendor\Doctrine\Common\Collections\Expr\Comparison::ENDS_WITH, new \WappoVendor\Doctrine\Common\Collections\Expr\Value($value));
    }
}
